#############################################################################
##                                                                         ##
##  main.gi                         PTREE                  Alexander Cant  ##
##                                                                         ##
#############################################################################

#############################################################################
##
##  Input:
##    p    a prime > 5
##    n    an integer
##
##  Output:
##    None, but the skeletons for prime p are computed starting at branch
##    Maximum( n, 2*p-8 ), stored to DIRLIB and visualized in DIRTEX.
##
FullSkeletons := function( p, n )
    local pt, filename;

    # check input
    if not ( IsInt( p ) and IsPrime( p ) and p > 5 and IsInt( n ) ) then
        ErrorNoReturn( "input has to be a prime > 5 and an integer" );
    fi;
    if n <= 2*p-8 then
        n := 2*p-8+1;
    fi;

    # compute skeletons, store them and print them as a tex-file
    while true do
        pt := Skeleton( p, n, 1, 0 );
        filename := Concatenation( "p", String( p ), "-s", String( n ) );
        PrintTreeToFile( pt, filename );
        pt := CompactTree( pt );
        TreeToLaTeX( pt, filename );
        n := n+1;
    od;
end;


#############################################################################
##
##  Input:
##    p    a prime > 5
##    n    an integer
##
##  Output:
##    None, but the the subtrees of the skeletons for prime p containing all
##    groups with Galois order <> 1 are computed starting at branch
##    Maximum( n, 2*p-8 ), stored to DIRLIB and visualized in DIRTEX.
##
AlmostFullSkeletons := function( p, n )
    local gal, pt, filename;

    # check input
    if not ( IsInt( p ) and IsPrime( p ) and p > 5 and IsInt( n ) ) then
        ErrorNoReturn( "input has to be a prime > 5 and an integer" );
    fi;
    if n <= 2*p-8 then
        n := 2*p-8+1;
    fi;

    # compute Galois orders
    gal := Filtered( DivisorsInt( p-1 ), x -> x <> 1 );

    # compute skeletons, store them and print them as a tex-file
    while true do
        pt := Skeleton( p, n, gal, 0 );
        filename := Concatenation( "p", String( p ), "-as", String( n ) );
        PrintTreeToFile( pt, filename );
        pt := CompactTree( pt );
        TreeToLaTeX( pt, filename );
        n := n+1;
    od;
end;

