#############################################################################
##                                                                         ##
##  print.gi                        PTREE                  Alexander Cant  ##
##                                                                         ##
#############################################################################

#############################################################################
##
##  Input:
##    pt    a p-tree
##    fn    a string
##
##  Output:
##    None, but pt is printed to the file "fn" in DIRLIB so that it can be
##    read again.
##
PrintTreeToFile := function( pt, fn )
    local file, i, j, k;

    # check input
    if not IsRecord( pt ) or not IsString( fn ) or IsEmpty( fn ) then
        ErrorNoReturn( "cannot handle the input" );
    fi;

    # check if file with intended name already exists
    file := Filename( DIRLIB, fn );
    if IsExistingFile( file ) then
        Error( "file already exists, 'return;' if it may be replaced" );
    fi;

    Print( " Printing p-tree to ", file, "...\n" );

    # print everything except pt.grp
    PrintTo( file, "" );
    AppendTo( file, "NEWPTREE := rec(\n" );
    AppendTo( file, Concatenation( "p := ", String( pt.p ), ",\n" ) );
    AppendTo( file, Concatenation( "n := ", String( pt.n ), ",\n" ) );
    AppendTo( file, Concatenation( "root := ", String( pt.root ), ",\n" ) );
    AppendTo( file, Concatenation( "dep := ", String( pt.dep ), ",\n" ) );
    AppendTo( file, Concatenation( "gal := ", String( pt.gal ), ",\n" ) );
    AppendTo( file, Concatenation( "info := ", String( pt.info ), ",\n" ) );
    AppendTo( file, Concatenation( "cmp := ", String( pt.cmp ), ",\n\n" ) );

    # print pt.grp
    AppendTo( file, "grp :=\n    [\n" );
    for i in [1..Length( pt.grp )] do
        AppendTo( file, "        [\n" );
        for j in [1..Length( pt.grp[i] )] do
            AppendTo( file, "            " );
            AppendTo( file, String( pt.grp[i][j] ) );
            if j < Length( pt.grp[i] ) then
                AppendTo( file, ",\n" );
            else
                AppendTo( file, "\n" );
            fi;
        od;
        if i < Length( pt.grp ) then
            AppendTo( file, "        ],\n" );
        else
            AppendTo( file, "        ]\n" );
        fi;
    od;
    AppendTo( file, "    ] );\n\n" );
    
    # print output on loaded tree
    AppendTo( file, "Print(\"loaded " );
    if pt.cmp then
        AppendTo( file, "compact " );
    fi;
    AppendTo( file, "p-tree NEWPTREE with p = " );
    AppendTo( file, String( pt.p ) );
    AppendTo( file, " in branch " );
    AppendTo( file, String( pt.n ) );
    AppendTo( file, " with Galois orders " );
    AppendTo( file, String( pt.gal ) );
    AppendTo( file, " and a root of size " );
    AppendTo( file, String( pt.p ) );
    AppendTo( file, "^" );
    AppendTo( file, String( pt.n + pt.dep ) );
    AppendTo( file, "\\n\");\n\n" );

    Print( " Done!\n\n" );
    
    return true;
end;

